@@ -33,6 +33,9 @@ class Preprocessing(DotWiz):
         x[target]=fn(x)
         return x
 
+    def load(self):
+        return self(datasets.load_dataset(self.dataset_name,self.config_name))
+
     def __call__(self,dataset, max_rows=None, max_rows_eval=None):
         dataset = self.pre_process(dataset)
         for k,v in zip(self.default_splits, self.splits):
@@ -53,7 +56,7 @@ class Preprocessing(DotWiz):
                                         and type(v)==str and k!=v)})
         for k in self.to_dict().keys():
             v=getattr(self, k)
-            if callable(v) and k not in {"post_process","pre_process"}:
+            if callable(v) and k not in {"post_process","pre_process","load"}:
                 dataset=dataset.map(self.__map_to_target,
                                     fn_kwargs={'fn':v,'target':k})
 
@@ -225,12 +228,11 @@ def fix_splits(dataset):
 def fix_labels(dataset, label_key='labels'):
     if type(dataset['train'][label_key][0]) in [int,list,float]:
         return dataset
-
-    label_to_index = fc.flip(dict(enumerate(sorted(set(fc.flatten(dataset[k][label_key] for k in {"train"}))))))
-
-    def apply_label_to_index(example):
-        example[label_key]=label_to_index[example[label_key]]
-        return example
-    dataset=dataset.map(apply_label_to_index)
-    dataset=dataset.cast_column(label_key, datasets.Value(dtype='int64'))
+    labels=set(fc.flatten(dataset[k][label_key] for k in {"train"}))
+    if set(labels)=={'entailment','neutral','contradiction'}:
+        order=lambda x:dict(fc.flip(enumerate(['entailment','neutral','contradiction']))).get(x,x)
+    else:
+        order=str
+    labels=sorted(labels, key=order)
+    dataset=dataset.cast_column(label_key, datasets.ClassLabel(names=labels))
     return dataset
\ No newline at end of file
